::: agentdojo.functions_runtime.FunctionsRuntime

::: agentdojo.functions_runtime.Function

::: agentdojo.functions_runtime.make_function

::: agentdojo.functions_runtime.Depends

::: agentdojo.functions_runtime.FunctionCall

::: agentdojo.functions_runtime.FunctionCallArgTypes

::: agentdojo.functions_runtime.FunctionReturnType

::: agentdojo.functions_runtime.TaskEnvironment

::: agentdojo.functions_runtime.EmptyEnv
